--[[Name: TranqShotMonitor
Description: Gives a message when tranquilizing Shot has dispelled succesfully, together with which buff was dispelled ]]

active = true
activechannel = false
TRchannel = "SAY"
local yourname = UnitName("player")
local tasks = {}
local prefix = "[TranqShotMonitor]"
local move = false
local channels = {"SAY", "PARTY", "BATTLEGROUND", "GUILD", "OFFICER", "YELL", "RAID", "RAID_WARNING"}
----------------------------
-- Timing Functions ------
----------------------------
function TimingLib_Schedule(time, func, ...)
	local t = {...}
	t.func = func
	t.time = GetTime() + time
	table.insert(tasks, t)
end

local function onUpdate(self, elapsed)
	for i = #tasks, 1, -1 do
		local val = tasks[i]
		if val and val.time <= GetTime() then
			table.remove(tasks, i)
			val.func(unpack(val))
		end
	end
end

function TimingLib_Unschedule(func, ...)
	for i = #tasks, 1 , -1 do
		local val = tasks[i]
		if val.func == func then
			local matches = true
			for i = 1, select("#", ...) do
				if select(i, ...) ~=val[i] then
					matches = false
					break
				end
			end
			if matches then
				table.remove(tasks, i)
			end
		end
	end
end

function SimpleTimingLib_Unschedule(func, ...)
	return unschedule(func, nil, ...)
end

function SimpleTimingLib_Schedule(time, func, ...)
	return schedule(time, func, nil, ...)
end

----------------------------------------
---- Handling the tranq shots --------
------------------------------------------

local frame = CreateFrame("Frame","TRANQWARNINGFRAME",UIParent)
frame:ClearAllPoints()
frame:SetPoint("TOP",UIParent)
frame:SetWidth(200)
frame:SetHeight(200)
frame:Show()

-----------------
-- warning ------
-----------------

local fontstring=frame:CreateFontString()
fontstring:ClearAllPoints()
fontstring:SetPoint("BOTTOM",frame)
fontstring:SetFont("Fonts\\FRIZQT__.TTF", 30)
fontstring:SetWidth(700)
fontstring:SetJustifyH("CENTER")
fontstring:SetHeight(40)

--------------------
-- help function ---
--------------------

local function isInList(channel)
	local b = false
	for i = 1, #channels do
		if channel == channels[i] then
			b = true
		end
	end
	return b
end
		


-------------------
-- event handler --
-------------------

function onEvent(self, event, ...)
	local tranqshotmsg = "Tranquilizing Shot dispelled "
	local soothemsg = "Soothe dispelled "
	local shivmsg = "Shiv dispelled "
	local timestamp, type, sourceGUID, sourceName, sourceFlags, destGUID, destName, destFlags = select(1, ...)

	if active == true and event == "COMBAT_LOG_EVENT_UNFILTERED" and sourceName == yourname then
		if (type=="SPELL_DISPEL") then
			local spellId, spellName, spellSchool = select(9, ...)
			local extraSpellID, extraSpellName, extraSchool, auraType = select(12, ...)
	
			if (spellName=="Tranquilizing Shot") then
				local msg = tranqshotmsg..extraSpellName.."!"
				fontstring:SetText(msg)
				fontstring:Show()
				TimingLib_Schedule(3, function() fontstring:Hide() end)
				if activechannel then
					local channel2 = TRchannel:upper()
					if isInList(channel2) then
						SendChatMessage("Dispelled "..extraSpellName.." off of "..destName, channel2)
					else
						index = GetChannelName(TRchannel)
						SendChatMessage("Dispelled "..extraSpellName.." off of "..destName, "CHANNEL", nil, index)
					end
				end
				

			end
			if spellName=="Soothe" then
				local msg = soothemsg..extraSpellName.."!"
				fontstring:SetText(msg)
				fontstring:Show()
				TimingLib_Schedule(3, function() fontstring:Hide() end)
				if activechannel then
					local channel2 = TRchannel:upper()
					if isInList(channel2) then
						SendChatMessage("Dispelled "..extraSpellName.." off of "..destName, channel2)
					else
						index = GetChannelName(TRchannel)
						SendChatMessage("Dispelled "..extraSpellName.." off of "..destName, "CHANNEL", nil, index)
					end
				end
				
			end
			if spellName=="Shiv" then
				local msg = shivmsg..extraSpellName.."!"
				fontstring:SetText(msg)
				fontstring:Show()
				TimingLib_Schedule(3, function() fontstring:Hide() end)
				if activechannel then
					local channel2 = TRchannel:upper()
					if isInList(channel2) then
						SendChatMessage("Dispelled "..extraSpellName.." off of "..destName, channel2)
					else
						index = GetChannelName(TRchannel)
						SendChatMessage("Dispelled "..extraSpellName.." off of "..destName, "CHANNEL", nil, index)
					end
				end
				
			end
		end
	end
end



frame:RegisterEvent("COMBAT_LOG_EVENT_UNFILTERED")
local e = 0
frame:SetScript("OnUpdate", function(self, elapsed)
	e  = e + elapsed
	if e >= 0.5 then
		e = 0
		return onUpdate(self, elapsed)
	end
end)

frame:SetScript("OnEvent", onEvent)

SLASH_TranqShotMonitor1 = "/tranqshotmonitor"
SLASH_TranqShotMonitor2 = "/tsm"

-----------------------------------
---- ---- slash commands-----------
---- /tsm enable        -----------
---- /tsm disable       -----------
---- /tsm channel enable ----------
---- /tsm channel disable ---------
---- /tsm setchannel <channel> ----
---- /tsm move enable ------------- NOT IMPLEMENTED YET
---- /tsm move disable ------------ NOT IMPLEMENTED YET
-----------------------------------

SlashCmdList["TranqShotMonitor"] = function(msg)
	local cmd, arg1 = string.split(" ", msg) --split the string
	cmd = cmd:lower() 
	if cmd == "enable" then -- /tsm enable
		active = true
		print(prefix.." Enabled")
	elseif cmd == "disable" then -- /tsm disable
		active = false
		print(prefix.." Disabled")
	elseif cmd == "channel" and arg1 == "enable" then
		activechannel = true
		print(prefix.." Channel notices enabled")
	elseif cmd == "channel" and arg1 == "disable" then
		activechannel = false
		print(prefix.." Channel notices disabled")
	elseif cmd == "setchannel" then
		if arg1 then
			TRchannel = arg1
			print(prefix.." Channel changed to "..arg1)
		end
	end
end
